@@ -1,48 +1,37 @@
 /*
-  Copyright (c) 2009 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #ifndef MAILCOMMON_BACKUPJOB_H
 #define MAILCOMMON_BACKUPJOB_H
 
 #include "mailcommon_export.h"
-#include "libkdepim/progressmanager.h"
+
+#include <Libkdepim/ProgressManager>
 
 #include <Collection>
 #include <Item>
 
 #include <QUrl>
 
+#include <QDateTime>
 #include <QObject>
 #include <QPointer>
-#include <QDateTime>
 
 class KArchive;
 class KJob;
 
 class QWidget;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class ItemFetchJob;
 }
 
-namespace MailCommon {
+namespace MailCommon
+{
 /**
  * Writes an entire folder structure to an archive file. The archive is
  * structured like a hierarchy of maildir folders. However, every type of
@@ -56,15 +45,10 @@ class MAILCOMMON_EXPORT BackupJob : public QObject
 
 public:
     // These enum values have to stay in sync with the format combobox of ArchiveFolderDialog!
-    enum ArchiveType {
-        Zip = 0,
-        Tar = 1,
-        TarBz2 = 2,
-        TarGz = 3
-    };
+    enum ArchiveType { Zip = 0, Tar = 1, TarBz2 = 2, TarGz = 3 };
 
     explicit BackupJob(QWidget *parent = nullptr);
-    ~BackupJob();
+    ~BackupJob() override;
 
     void setRootFolder(const Akonadi::Collection &rootFolder);
     void setSaveLocation(const QUrl &savePath);
@@ -103,23 +87,23 @@ private:
     QString mRealPath;
     QUrl mMailArchivePath;
     QDateTime mArchiveTime;
-    ArchiveType mArchiveType;
+    ArchiveType mArchiveType = Zip;
     Akonadi::Collection mRootFolder;
-    KArchive *mArchive;
-    QWidget *mParentWidget;
-    int mArchivedMessages;
-    uint mArchivedSize;
+    KArchive *mArchive = nullptr;
+    QWidget *const mParentWidget;
+    int mArchivedMessages = 0;
+    uint mArchivedSize = 0;
     QPointer<KPIM::ProgressItem> mProgressItem;
-    bool mAborted;
-    bool mDeleteFoldersAfterCompletion;
-    bool mRecursive;
+    bool mAborted = false;
+    bool mDeleteFoldersAfterCompletion = false;
+    bool mRecursive = true;
 
     Akonadi::Collection::List mPendingFolders;
     Akonadi::Collection::List mAllFolders;
     Akonadi::Collection mCurrentFolder;
     Akonadi::Item::List mPendingMessages;
-    Akonadi::ItemFetchJob *mCurrentJob;
-    bool mDisplayMessageBox;
+    Akonadi::ItemFetchJob *mCurrentJob = nullptr;
+    bool mDisplayMessageBox = true;
 };
 }
 
